def get_elided_page_range(current_page, total_pages, display_count=5):
    if total_pages <= display_count:
        return list(range(1, total_pages + 1))

    # Determine the range of pages to display around the current page
    start_range = max(1, current_page - (display_count // 2))
    end_range = min(total_pages, start_range + display_count - 1)

    # Adjust the range if it reaches the start or end
    if end_range - start_range + 1 < display_count:
        start_range = max(1, end_range - display_count + 1)
    if end_range - start_range + 1 < display_count:
        end_range = min(total_pages, start_range + display_count - 1)

    # Add elision if necessary
    page_range = []
    if start_range > 1:
        page_range.append(1)
        if start_range > 2:
            page_range.append(None)

    page_range.extend(range(start_range, end_range + 1))

    if end_range < total_pages:
        if end_range < total_pages - 1:
            page_range.append(None)
        page_range.append(total_pages)

    return page_range


from cryptography.fernet import Fernet
secret_words = {
        "T!4": "0",
        "Tc1": "9",
        "A2e": "8",
        "H3M": "7",
        "Y!3": "6",
        "A3G": "5",
        "H!2": "4",
        "YkZ": "3",
        "Whe": "2",
        "B!G": "1",
        "B!q": "/",
        "T!Q": "=",
        "P!u": "z",
        "A!u": "y",
        "H!Q": "x",
        "HIZ": "w",
        "WIZ": "v",
        "WKM": "u",
        "HXZ": "t",
        "HUM": "s",
        "A*Z": "r",
        "ÝVZ": "q",
        "ŸXZ": "p",
        "™UZ": "o",
        "þUZ": "n",
        "šUZ": "m",
        "æXZ": "l",
        "ÑXZ": "k",
        "ŠVZ": "j",
        "ÞXZ": "i",
        "ýVZ": "h",
        "ÇVZ": "g",
        "ñVZ": "f",
        "ŽXZ": "e",
        "ßXZ": "d",
        "ŒXZ": "c",
        "ðXZ": "b",
        "žXZ": "a",
    }

def strtr(strng, replace):
    if replace and strng:
        s, r = replace.popitem()
        return r.join(strtr(subs, dict(replace)) for subs in strng.split(s))
    return strng


def encryptString(msg,KEY):
    if  msg and not "encrypt" in msg:
        fernet = Fernet(KEY)
        newmsg = strtr(msg, secret_words)
        secret = fernet.encrypt(bytes(newmsg, 'utf-8'))
        return secret.decode("utf-8")[::-1] + "encrypted"
    return msg



def decryptString(msg,KEY):
    if  msg and "encrypted" in msg:
        msg = msg.replace("encrypted","")[::-1]
        fernet = Fernet(KEY)
        msg = fernet.decrypt(bytes(msg, 'utf-8')).decode()
        newmsg = strtr(msg, secret_words)
        return newmsg
    return msg




# from datetime import datetime
# import uuid
# from time import time
# import base64
# import datetime
# from api.models import OTP


# def generateKey(email):
#     key_string = str(email) + "FGH#^&TYE&V*EV^&U#H$R*&H&*$F(Y*GHT$*O(GT$&)))"
#     return base64.b32encode(key_string.encode())


# def generate_OTP(request, user=None, email=None, template=None, subject=None):
#     key = generateKey(email)
#     otp_code = str(uuid.uuid1())[:6]

#     if OTP.objects.filter(key=key).exists():
#         OTP.objects.filter(key=key).delete()

#     try:

#         otp_model = OTP.objects.create(key=key, otp=otp_code)

#     except:
#         return None
    
#     return otp_model.otp


# def verify_OTP(otp, email):
#     key = generateKey(email)

#     if OTP.objects.filter(key=key).exists():
#         otpmodel = OTP.objects.get(key=key)
#         expire_time = otpmodel.created_date + datetime.timedelta(minutes=5)

#         if expire_time < datetime.datetime.now():
#             OTP.objects.filter(key=key).delete()
#             return {
#                 "is_verify": False,
#                 "message": "OTP has been Expired, generate new OTP",
#             }

#         elif otp == otpmodel.otp:

#             OTP.objects.filter(key=key).delete()
#             return {"is_verify": True, "message": "OTP verified"}

#         else:
#             return {"is_verify": False, "message": "Incorrect OTP"}
#     else:
#         return {"is_verify": False, "message": "Invalid OTP"}



# setup.py
from setuptools import setup, find_packages

setup(
   name="vesselPackage",
   author="unknow",
   description="unknow",
   packages=find_packages(),
   include_package_data=True,
   classifiers=[
    "Development Status :: 3 - Alpha",
    "Operating System :: OS Independent",
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python :: 3"
],
   python_requires='>=3.6',
   setup_requires=['setuptools-git-versioning'],
   version_config={
       "dirty_template": "{tag}",
   }
)